Learn R Programming

DSBayes (version 2023.1.0)

DSBayes-package: Bayesian subgroup analysis in clinical trials

Description

Calculate posterior modes and credible intervals of parameters of the Dixon-Simon model for subgroup analysis (with binary covariates) in clinical trials.

Arguments

Author

Ravi Varadhan <rvaradhan@jhmi.edu> and Wenliang Yao <yaow080@gmail.com>

Details

Package:DSBayes
Version:1.1
Date:Dec 27, 2013
Depends:R (>= 2.15.1)
Imports:BB
License:GPL Version 2

The main functions in this package are:

DSBayes: A function to calculate the posterior mode and credible interval of the parameters in the Dixon-Simon model, as well as the MLE regression coefficients.

References

Dixon D. and Simon R. (1991). Bayesian Subset Analysis. Biometrics, 47, 871-881